======================================
``models``: Bibliographic data classes
======================================

.. automodule:: relaton.models

.. contents::
   :local:

Bibliographic data
==================

.. automodule:: relaton.models.bibdata
   :members:
   :undoc-members:
   :exclude-members: __init__
   :show-inheritance:

Copyrights
==========

.. automodule:: relaton.models.copyrights
   :members:
   :undoc-members:
   :exclude-members: __init__
   :show-inheritance:

People
======

.. automodule:: relaton.models.people
   :members:
   :undoc-members:
   :exclude-members: __init__
   :show-inheritance:

Organizations
=============

.. automodule:: relaton.models.orgs
   :members:
   :undoc-members:
   :exclude-members: __init__
   :show-inheritance:

Contacts
========

.. automodule:: relaton.models.contacts
   :members:
   :undoc-members:
   :exclude-members: __init__
   :show-inheritance:

Links
=====

.. automodule:: relaton.models.links
   :members:
   :undoc-members:
   :exclude-members: __init__
   :show-inheritance:

Dates
=====

.. automodule:: relaton.models.dates
   :members:
   :undoc-members:
   :exclude-members: __init__
   :show-inheritance:

Strings
=======

.. automodule:: relaton.models.strings
   :members:
   :undoc-members:
   :exclude-members: __init__
   :show-inheritance:
